Index: main/rtp.c
===================================================================
--- main/rtp.c	(revision 85355)
+++ main/rtp.c	(working copy)
@@ -77,6 +77,7 @@
 
 static int dtmftimeout = DEFAULT_DTMF_TIMEOUT;
 
+static int disablep2p;			/*!< Disable Packet2Packet Bridging */
 static int rtpstart;			/*!< First port for RTP sessions (set in rtp.conf) */
 static int rtpend;			/*!< Last port for RTP sessions (set in rtp.conf) */
 static int rtpdebug;			/*!< Are we debugging? */
@@ -3329,8 +3330,12 @@
 		return AST_BRIDGE_FAILED_NOWARN;
 	}
 
+	if (disablep2p && option_debug) {
+		ast_log(LOG_DEBUG, "Packet2packet bridging is disabled in rtp.conf\n");
+	}
+
 	/* If either side can only do a partial bridge, then don't try for a true native bridge */
-	if (audio_p0_res == AST_RTP_TRY_PARTIAL || audio_p1_res == AST_RTP_TRY_PARTIAL) {
+	if ((!disablep2p) && (audio_p0_res == AST_RTP_TRY_PARTIAL || audio_p1_res == AST_RTP_TRY_PARTIAL)) {
 		struct ast_format_list fmt0, fmt1;
 
 		/* In order to do Packet2Packet bridging both sides must be in the same rawread/rawwrite */
@@ -3687,11 +3692,15 @@
 	struct ast_config *cfg;
 	const char *s;
 
+	disablep2p = 0;
 	rtpstart = 5000;
 	rtpend = 31000;
 	dtmftimeout = DEFAULT_DTMF_TIMEOUT;
 	cfg = ast_config_load("rtp.conf");
 	if (cfg) {
+		if ((s = ast_variable_retrieve(cfg, "general", "disablep2p"))) {
+			disablep2p = ast_true(s);
+}
 		if ((s = ast_variable_retrieve(cfg, "general", "rtpstart"))) {
 			rtpstart = atoi(s);
 			if (rtpstart < 1024)
